<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Email\Models\Email;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Enums\InertiaMethod;

Form::make('email.show')
    ->addFields(function () {
        return [
            Section::make('Details')->fields([
                Display::make('Type'),
                Display::make('Subject'),
                Display::make('Sender Email')
                    ->name('sender_address'),
                Display::make('Reply-To Email')
                    ->name('reply_to_address'),
            ]),
        ];
    })
    ->addActions(function (Email $email) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.index', [
                    'event' => $email->event->id,
                ]),
            Button::make('Edit Email')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.edit', [
                    'event' => $email->event->id,
                    'email' => $email->id,
                ]),
        ];
    });

Form::make('email.edit')
    ->addSaveHandler(new UpdateModel)
    ->addFields(function () {
        return [
            Section::make('Details')->fields([
                Display::make('Type'),
                Text::make('Subject')
                    ->placeholder('You\'re invited!')
                    ->rules(['required']),
                Text::make('Sender Email')
                    ->name('sender_address')
                    ->placeholder('info@example.com')
                    ->rules(['nullable', 'email']),
                Text::make('Reply-To Email')
                    ->name('reply_to_address')
                    ->placeholder('info@example.com')
                    ->rules(['nullable', 'email']),
            ]),
        ];
    })
    ->addActions(function (Email $email) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.index', [
                    'event' => $email->event->id,
                ]),
            Button::make('Update Email')
                ->method(InertiaMethod::POST())
                ->route('admin.email.update', [
                    'event' => $email->event->id,
                    'email' => $email->id,
                ]),
        ];
    });
