<?php

namespace EventPortal\Domain\User\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Speaker\Models\Speaker;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable implements AuditableInterface
{
    use Notifiable, AddToFillable, AddToCasts, Auditable, HasRoles;

    const KEY = 'user';

    /** @var array */
    protected $fillable = [
        'first_name',
        'last_name',
        'email',
        'password',
        'password_created_at',
    ];

    /** @var array<string> */
    protected $dates = [
        'password_created_at',
    ];

    public function delegate(): HasOne
    {
        return $this->HasOne(Delegate::class);
    }

    public function speaker(): HasOne
    {
        return $this->HasOne(Speaker::class);
    }

    public function admin(): HasOne
    {
        return $this->hasOne(Admin::class);
    }

    public function getFullNameAttribute(): string
    {
        return trim(implode(' ', [$this->first_name, $this->last_name]));
    }

    public function isAdmin(): bool
    {
        return $this->admin()->exists();
    }
}
