<?php

namespace EventPortal\Http\Controllers\Admin\EventSpeaker;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Domain\Util\Render;
use EventPortal\Domain\Util\Sidebar\Facades\Sidebar;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Eloquent\Builder;
use Inertia\Response;

class SpeakersNotOnEventController extends Controller
{
    public function index(Event $event): Response
    {
        $query = Speaker::query()
            ->whereDoesntHave('events', function (Builder $query) use ($event) {
                return $query->where('event_id', '=', $event->id);
            })
            ->joinRelationship('user');

        $table = Table::make('event-speaker.add')
            ->context($event)
            ->query($query)
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('Speakers', route('admin.event.speaker.index', $event))
            ->add('Add speaker')
            ->get();

        $sidebar = Sidebar::make('event.show')
            ->user(auth()->user())
            ->model(request()->event)
            ->render();

        return Render::component('Admin/EventSpeaker/Add')
            ->key('event.speaker.add')
            ->withTable($table)
            ->withBreadcrumbs($breadcrumbs)
            ->attributes(['event' => $event])
            ->withSideBar($sidebar)
            ->get();
    }
}
