<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Util\Statistics\Facades\Statistics;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class StatisticsTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;
    /** @test */
    public function the_statistic_can_be_generated_for_an_event()
    {
        $event = factory(Event::class)->create([
            'name' => 'Event name',
            'url' => 'event-name',
        ]);

        $statistics = Statistics::make('events.show')
            ->add('Stats 1', static function (Event $event): string {
                return $event->name;
            })
            ->add('Stats 2', static function (Event $event): string {
                return $event->url;
            })
            ->model($event)
            ->render();

        $this->assertMatchesJsonSnapshot($statistics);
    }

    /** @test */
    public function get_correct_statistics_by_name()
    {
        $event = factory(Event::class)->create([
            'name' => 'Event name',
            'url' => 'event-name',
        ]);

        Statistics::make('one')
            ->add('Stats 1', static function (Event $event): string {
                return 'one';
            });

        Statistics::make('two')
            ->add('Stats 1', static function (Event $event): string {
                return 'two';
            });

        $statsOne = Statistics::make('one')
            ->model($event)
            ->render();

        $statsTwo = Statistics::make('two')
            ->model($event)
            ->render();

        $this->assertMatchesJsonSnapshot($statsOne);
        $this->assertMatchesJsonSnapshot($statsTwo);
    }
}
